@@ -1,36 +1,37 @@
 #' Plot a map labelled with the ID numbering
 #'
-#' The \code{spnet.map.plot.position} function allows to plot maps defined as for example \code{SpatialNetwork} or \code{SpatialPolygons} objects, and render the ID numbering.
+#' The \code{graph.map.plot.position} function allows to plot maps defined as for example \code{SpatialNetwork} or \code{SpatialPolygons} objects, and render the ID numbering.
 #'
-#' @param x an object for which a \code{spnet.map.plot.position} method is defined.
+#' @param x an object for which a \code{graph.map.plot.position} method is defined.
 #' @param label a character of length 1 for prefixing seat numbering.
 #' @param ... other arguments to pass to the plot function. The main usage is setting the \code{cex} value.
 #'
 #' @return NULL
 #' 
 #' @family plot map
+#' @importFrom graphics text
 #' @export
 #' @examples
 #' ## The world map
 #' data(world.map.simplified, package = "spnet")
 #'
-#' spnet.map.plot.position(world.map.simplified)
-#' spnet.map.plot.position(world.map.simplified, cex = 0.4)
-#' spnet.map.plot.position(world.map.simplified, label = 'ID ', cex = 0.3)
+#' graph.map.plot.position(world.map.simplified)
+#' graph.map.plot.position(world.map.simplified, cex = 0.4)
+#' graph.map.plot.position(world.map.simplified, label = 'ID ', cex = 0.3)
 setGeneric(
-  'spnet.map.plot.position',
+  'graph.map.plot.position',
   function(
     x,
     label = '',
     ...
   ) {
-    standardGeneric("spnet.map.plot.position")
+    standardGeneric("graph.map.plot.position")
   }
 )
 
-#' @describeIn spnet.map.plot.position method for \code{SpatialPolygons} objects.
+#' @describeIn graph.map.plot.position method for \code{SpatialPolygons} objects.
 setMethod(
-  f = 'spnet.map.plot.position',
+  f = 'graph.map.plot.position',
   signature = 'SpatialPolygons',
   definition = function(x, label, ...) {
     if(length(x) == 0)
@@ -40,13 +41,13 @@ setMethod(
   }
 )
 
-#' @describeIn spnet.map.plot.position method for \code{SpatialNetwork} objects.
+#' @describeIn graph.map.plot.position method for \code{SpatialNetwork} objects.
 setMethod(
-  f = 'spnet.map.plot.position',
+  f = 'graph.map.plot.position',
   signature = 'SpatialNetwork',
   definition = function(x, label, ...) {
     if(length(x@map) == 0)
       stop("The map is empty. Please define a valid map.")
-    getMethod('spnet.map.plot.position', 'SpatialPolygons')(x@map, label, ...)
+    getMethod('graph.map.plot.position', 'SpatialPolygons')(x@map, label, ...)
   }
 )
\ No newline at end of file
